@@ -115,7 +115,8 @@ nil means let mailer mail back a message to report errors.")
 
 ;; Useful to set in site-init.el
 ;;;###autoload
-(defvar send-mail-function (if (eq system-type 'windows-nt)
+(defvar send-mail-function (if (or (eq system-type 'windows-nt)
+				   (eq system-type 'cygwin32))
 			       ;; there is no sendmail on windows.
 			       'smtpmail-send-it
 			     'sendmail-send-it)
