@@ -1,4 +1,6 @@
 ;;; smtpmail.el --- simple SMTP protocol (RFC 821) for sending mail
+;;; ###	Hacked by Mike Taylor, 11th October 1999 to add support for
+;;;	automatically appending a domain to RCPT TO: addresses.
 
 ;; Copyright (C) 1995, 1996 Free Software Foundation, Inc.
 
@@ -38,6 +40,7 @@
 ;;(setq message-send-mail-function 'smtpmail-send-it) ; if you use `message'
 ;;(setq smtpmail-default-smtp-server "YOUR SMTP HOST")
 ;;(setq smtpmail-local-domain "YOUR DOMAIN NAME")
+;;(setq smtpmail-sendto-domain "YOUR DOMAIN NAME")
 ;;(setq smtpmail-debug-info t) ; only to debug problems
 ;;(load-library "smtpmail")
 ;;(setq smtpmail-code-conv-from nil)
@@ -102,6 +105,28 @@ don't define this value."
   :type '(choice (const nil) string)
   :group 'smtpmail)
 
+(defcustom smtpmail-sendto-domain nil
+  "*Local domain name without a host name.
+This is appended (with an @-sign) to any specified recipients which do
+not include an @-sign, so that each RCPT TO address is fully qualified.
+\(Some configurations of sendmail require this.)
+
+Don't bother to set this unless you have get an error like:
+	Sending failed; SMTP protocol error
+when sending mail, and the *trace of SMTP session to <somewhere>*
+buffer includes an exchange like:
+	RCPT TO: <someone>
+	501 <someone>: recipient address must contain a domain
+"
+  :type '(choice (const nil) string)
+  :group 'smtpmail)
+
+(defun maybe-append-domain (recipient)
+  (if (or (not smtpmail-sendto-domain)
+	  (string-match "@" recipient))
+      recipient
+    (concat recipient "@" smtpmail-sendto-domain)))
+
 (defcustom smtpmail-debug-info nil
   "*smtpmail debug info printout. messages and process buffer."
   :type 'boolean
@@ -217,7 +242,7 @@ This is relative to `smtpmail-queue-dir'.")
 	    ;; they put one in themselves.
 	    (goto-char (point-min))
 	    (if (not (re-search-forward "^From:" delimline t))
-		(let* ((login (user-mail-address))
+		(let* ((login (user-mail-address)) ;; XEmacs
 		       (fullname (user-full-name)))
 		  (cond ((eq mail-from-style 'angles)
 			 (insert "From: " fullname)
@@ -568,7 +593,7 @@ This is relative to `smtpmail-queue-dir'.")
 		     "")))
 ;	      (smtpmail-send-command process (format "MAIL FROM:%s@%s" (user-login-name) (smtpmail-fqdn)))
 	      (smtpmail-send-command process (format "MAIL FROM: <%s>%s%s"
-						     user-mail-address
+						     (user-mail-address) ;; XEmacs
 						     size-part
 						     body-part))
 
@@ -581,7 +606,7 @@ This is relative to `smtpmail-queue-dir'.")
 	    ;; RCPT TO: <recipient>
 	    (let ((n 0))
 	      (while (not (null (nth n recipient)))
-		(smtpmail-send-command process (format "RCPT TO: <%s>" (nth n recipient)))
+		(smtpmail-send-command process (format "RCPT TO: <%s>" (maybe-append-domain (nth n recipient))))
 		(setq n (1+ n))
 
 		(setq response-code (smtpmail-read-response process))
